import os
import sys
from team import Team
from match_simulator import Model, MatchSimulator
import json
import numpy as np


def main():

    #Initialize the model
    model_dir = '.\\model_versions\\revisit_bs-128_dropout-0.4_lr-static\\'
    model = Model(model_dir, 'ball_prediction', 'bs-128_dropout-0.4_lr-static_adam_epoch-25_ball-predict')
    ball_pred_model = model.get_model()

    #Loading hist stats
    bat_stats_file = '.\\data\\player_stats\\batsman_stats.json'
    bowl_stats_file = '.\\data\\player_stats\\bowler_stats.json'

    with open(bat_stats_file, 'r') as j:
        bat_stats = json.loads(j.read())
    
    with open(bowl_stats_file, 'r') as j:
        bowl_stats = json.loads(j.read())

    #list of players
    #Important - The order of the list is important as that will be the batting order for batting.
    team1_players = ["AB de Villiers",
        "CH Gayle",
        "V Kohli",
        "SS Tiwary",
        "MA Agarwal",
        "M Kaif",
        "LA Pomersbach",
        "DL Vettori",
        "S Aravind",
        "A Mithun",
        "Z Khan" ]

    team2_players = ["MEK Hussey",
        "M Vijay",
        "SK Raina",
        "S Badrinath",
        "WP Saha",
        "MS Dhoni",
        "DJ Bravo",
        "JA Morkel",
        "R Ashwin",
        "SB Jakati",
        "DE Bollinger" ]

    team1 = Team('RCB', team1_players, bat_stats, bowl_stats)
    team2 = Team('CSK', team2_players, bat_stats, bowl_stats)

    simulator = MatchSimulator(team1, team2, log_verbosity=True, model=ball_pred_model)
    outcomes = simulator.simulate_match()

    print('\n\n')
    print('*'*30)
    print('Winner of the match is: {}'.format(outcomes[0]))
    print('Stats of {}\nRuns Scored: {}/{}'.format(outcomes[1][0], outcomes[1][1], outcomes[1][2]))
    print('Player stats: {}'.format(outcomes[1][3]))

    print('\n\n')
    print('*'*30)
    print('Stats of {}\nRuns Scored: {}/{}'.format(outcomes[2][0], outcomes[2][1], outcomes[2][2]))
    print('Player stats: {}'.format(outcomes[2][3]))


    return True




if __name__=='__main__':
    if main():
        sys.exit(0)
    else:
        sys.exit(1)
